@@ -65,6 +65,7 @@ struct _AsAppClass
  * @AS_APP_PARSE_FLAG_APPEND_DATA:	Append new data rather than replacing
  * @AS_APP_PARSE_FLAG_ALLOW_VETO:	Do not return errors for vetoed apps
  * @AS_APP_PARSE_FLAG_USE_FALLBACKS:	Fall back to suboptimal data where required
+ * @AS_APP_PARSE_FLAG_ADD_ALL_METADATA:	Add all extra metadata from the source file
  *
  * The flags to use when parsing resources.
  **/
@@ -76,6 +77,7 @@ typedef enum {
 	AS_APP_PARSE_FLAG_APPEND_DATA		= 8,	/* Since: 0.1.8 */
 	AS_APP_PARSE_FLAG_ALLOW_VETO		= 16,	/* Since: 0.2.5 */
 	AS_APP_PARSE_FLAG_USE_FALLBACKS		= 32,	/* Since: 0.4.1 */
+	AS_APP_PARSE_FLAG_ADD_ALL_METADATA	= 64,	/* Since: 0.5.18 */
 	/*< private >*/
 	AS_APP_PARSE_FLAG_LAST,
 } AsAppParseFlags;
@@ -217,6 +219,10 @@ typedef enum {
  * @AS_APP_QUIRK_COMPULSORY:		Cannot be removed
  * @AS_APP_QUIRK_HAS_SOURCE:		Has a source to allow staying up-to-date
  * @AS_APP_QUIRK_MATCH_ANY_PREFIX:	Matches applications with any prefix
+ * @AS_APP_QUIRK_NEEDS_REBOOT:		A reboot is required after the action
+ * @AS_APP_QUIRK_NOT_REVIEWABLE:	The app is not reviewable
+ * @AS_APP_QUIRK_HAS_SHORTCUT:		The app has a shortcut in the system
+ * @AS_APP_QUIRK_NOT_LAUNCHABLE:	The app is not launchable (run-able)
  *
  * The component attributes.
  **/
@@ -226,6 +232,10 @@ typedef enum {
 	AS_APP_QUIRK_COMPULSORY		= 1 << 1,	/* Since: 0.5.10 */
 	AS_APP_QUIRK_HAS_SOURCE		= 1 << 2,	/* Since: 0.5.10 */
 	AS_APP_QUIRK_MATCH_ANY_PREFIX	= 1 << 3,	/* Since: 0.5.12 */
+	AS_APP_QUIRK_NEEDS_REBOOT	= 1 << 4,	/* Since: 0.5.14 */
+	AS_APP_QUIRK_NOT_REVIEWABLE	= 1 << 5,	/* Since: 0.5.14 */
+	AS_APP_QUIRK_HAS_SHORTCUT	= 1 << 6,	/* Since: 0.5.15 */
+	AS_APP_QUIRK_NOT_LAUNCHABLE	= 1 << 7,	/* Since: 0.5.15 */
 	/*< private >*/
 	AS_APP_QUIRK_LAST
 } AsAppQuirk;
@@ -242,6 +252,8 @@ typedef enum {
  * @AS_APP_STATE_INSTALLING:			Application is being installed
  * @AS_APP_STATE_REMOVING:			Application is being removed
  * @AS_APP_STATE_UPDATABLE_LIVE:		Application is installed and updatable live
+ * @AS_APP_STATE_PURCHASABLE:			Application is available for purchasing
+ * @AS_APP_STATE_PURCHASING:			Application is being purchased
  *
  * The application state.
  **/
@@ -256,6 +268,8 @@ typedef enum {
 	AS_APP_STATE_INSTALLING,			/* Since: 0.2.2 */
 	AS_APP_STATE_REMOVING,				/* Since: 0.2.2 */
 	AS_APP_STATE_UPDATABLE_LIVE,			/* Since: 0.5.4 */
+	AS_APP_STATE_PURCHASABLE,			/* Since: 0.5.17 */
+	AS_APP_STATE_PURCHASING,			/* Since: 0.5.17 */
 	/*< private >*/
 	AS_APP_STATE_LAST
 } AsAppState;
