@@ -96,6 +96,10 @@ as_bundle_kind_from_string (const gchar *kind)
 		return AS_BUNDLE_KIND_FLATPAK;
 	if (g_strcmp0 (kind, "flatpak") == 0)
 		return AS_BUNDLE_KIND_FLATPAK;
+	if (g_strcmp0 (kind, "snap") == 0)
+		return AS_BUNDLE_KIND_SNAP;
+	if (g_strcmp0 (kind, "package") == 0)
+		return AS_BUNDLE_KIND_PACKAGE;
 	return AS_BUNDLE_KIND_UNKNOWN;
 }
 
@@ -116,6 +120,10 @@ as_bundle_kind_to_string (AsBundleKind kind)
 		return "limba";
 	if (kind == AS_BUNDLE_KIND_FLATPAK)
 		return "flatpak";
+	if (kind == AS_BUNDLE_KIND_SNAP)
+		return "snap";
+	if (kind == AS_BUNDLE_KIND_PACKAGE)
+		return "package";
 	return NULL;
 }
 
