@@ -114,6 +114,7 @@ static gboolean	as_store_from_file_internal (AsStore *store,
 					     GFile *file,
 					     const gchar *id_prefix,
 					     const gchar *arch,
+					     AsStoreWatchFlags watch_flags,
 					     GCancellable *cancellable,
 					     GError **error);
 
@@ -608,6 +609,7 @@ as_store_get_app_by_id_with_fallbacks (AsStore *store, const gchar *id)
 		{ "kanagram.desktop",		"org.kde.kanagram.desktop" },
 		{ "kapman.desktop",		"org.kde.kapman.desktop" },
 		{ "kbruch.desktop",		"org.kde.kbruch.desktop" },
+		{ "kdevelop.desktop",		"org.kde.kdevelop.desktop" },
 		{ "kgeography.desktop",		"org.kde.kgeography.desktop" },
 		{ "khangman.desktop",		"org.kde.khangman.desktop" },
 		{ "kig.desktop",		"org.kde.kig.desktop" },
@@ -628,6 +630,7 @@ as_store_get_app_by_id_with_fallbacks (AsStore *store, const gchar *id)
 		{ "partitionmanager.desktop",	"org.kde.PartitionManager.desktop" },
 		{ "picmi.desktop",		"org.kde.picmi.desktop" },
 		{ "rocs.desktop",		"org.kde.rocs.desktop" },
+		{ "skrooge.desktop",		"org.kde.skrooge.desktop" },
 		{ "step.desktop",		"org.kde.step.desktop" },
 
 		/* others */
@@ -1340,16 +1343,21 @@ as_store_watch_source_added (AsStore *store, const gchar *filename)
 	/* we helpfully saved this */
 	dirname = g_path_get_dirname (filename);
 	g_debug ("parsing new file %s from %s", filename, dirname);
-	path_data = g_hash_table_lookup (priv->appinfo_dirs, dirname);
+	path_data = g_hash_table_lookup (priv->appinfo_dirs, filename);
+	if (path_data == NULL)
+		path_data = g_hash_table_lookup (priv->appinfo_dirs, dirname);
 	if (path_data == NULL) {
 		g_warning ("no path data for %s", dirname);
 		return;
 	}
 	file = g_file_new_for_path (filename);
+	/* Do not watch the file for changes: we're already watching its
+	 * parent directory */
 	if (!as_store_from_file_internal (store,
 					  file,
 					  path_data->id_prefix,
 					  path_data->arch,
+					  AS_STORE_WATCH_FLAG_NONE,
 					  NULL, /* cancellable */
 					  &error)){
 		g_warning ("failed to rescan: %s", error->message);
@@ -1437,13 +1445,6 @@ as_store_add_path_data (AsStore *store,
 		return;
 	}
 
-	/* check is a directory */
-	if (!g_file_test (path, G_FILE_TEST_IS_DIR)) {
-		g_warning ("not adding path %s [%s:%s] as not a directory",
-			   path, id_prefix, arch);
-		return;
-	}
-
 	/* check not already exists */
 	path_data = g_hash_table_lookup (priv->appinfo_dirs, path);
 	if (path_data != NULL) {
@@ -1471,6 +1472,7 @@ as_store_from_file_internal (AsStore *store,
 			     GFile *file,
 			     const gchar *id_prefix,
 			     const gchar *arch,
+			     AsStoreWatchFlags watch_flags,
 			     GCancellable *cancellable,
 			     GError **error)
 {
@@ -1512,7 +1514,8 @@ as_store_from_file_internal (AsStore *store,
 	}
 
 	/* watch for file changes */
-	if (priv->watch_flags > 0) {
+	if (watch_flags > 0) {
+		as_store_add_path_data (store, filename, id_prefix, arch);
 		if (!as_monitor_add_file (priv->monitor,
 					  filename,
 					  cancellable,
@@ -1552,9 +1555,12 @@ as_store_from_file (AsStore *store,
 		    GCancellable *cancellable,
 		    GError **error)
 {
+	AsStorePrivate *priv = GET_PRIVATE (store);
+
 	return as_store_from_file_internal (store, file,
 					    NULL, /* id_prefix */
 					    NULL, /* arch */
+					    priv->watch_flags,
 					    cancellable, error);
 }
 
@@ -2179,10 +2185,13 @@ as_store_load_app_info_file (AsStore *store,
 		return FALSE;
 
 	file = g_file_new_for_path (path_xml);
+	/* Do not monitor the file: assume we are already monitoring its
+	 * directory */
 	return as_store_from_file_internal (store,
 					    file,
 					    id_prefix,
 					    arch,
+					    AS_STORE_WATCH_FLAG_NONE,
 					    cancellable,
 					    error);
 }
@@ -2330,6 +2339,9 @@ as_store_load_installed (AsStore *store,
 	/* emit once when finished */
 	tok = as_store_changed_inhibit (store);
 
+	/* always load all the .desktop 'X-' metadata */
+	parse_flags |= AS_APP_PARSE_FLAG_ADD_ALL_METADATA;
+
 	/* relax the checks when parsing */
 	if (flags & AS_STORE_LOAD_FLAG_ALLOW_VETO)
 		parse_flags |= AS_APP_PARSE_FLAG_ALLOW_VETO;
